
# Slot: has input


holds between a process and a continuant, where the continuant is an input into the process

URI: [biolink:has_input](https://w3id.org/biolink/vocab/has_input)


## Domain and Range

[Occurrent](Occurrent.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [has participant](has_participant.md)

## Children

 *  [molecular activity➞has input](molecular_activity_has_input.md)

## Used by

 * [Behavior](Behavior.md)
 * [BehavioralExposure](BehavioralExposure.md)
 * [BehavioralOutcome](BehavioralOutcome.md)
 * [BiologicalProcess](BiologicalProcess.md)
 * [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)
 * [Death](Death.md)
 * [MortalityOutcome](MortalityOutcome.md)
 * [PathologicalProcess](PathologicalProcess.md)
 * [PathologicalProcessExposure](PathologicalProcessExposure.md)
 * [PathologicalProcessOutcome](PathologicalProcessOutcome.md)
 * [Pathway](Pathway.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)
 * [SocioeconomicExposure](SocioeconomicExposure.md)
 * [SocioeconomicOutcome](SocioeconomicOutcome.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002233 |
|  | | SEMMEDDB:USES |
|  | | SEMMEDDB:uses |
| **Close Mappings:** | | RO:0002352 |
| **Narrow Mappings:** | | LOINC:has_fragments_for_synonyms |
|  | | LOINC:has_system |
|  | | PathWhiz:has_left_element |
|  | | RO:0002590 |
|  | | RO:0004009 |
|  | | SNOMED:has_finding_method |
|  | | SNOMED:has_precondition |
|  | | SNOMED:has_specimen_source_identity |
|  | | SNOMED:has_specimen_substance |
|  | | SNOMED:uses_access_device |
|  | | SNOMED:uses_device |
|  | | SNOMED:uses_energy |
|  | | SNOMED:uses_substance |

